import { JsonOption } from '../util/json-option';
import { Jsonable } from './jsonable';
export declare class AdditionalData extends Jsonable {
    data: {
        [name: string]: JsonOption;
    };
    /**
       * Convert a JSON string into an {@link AdditionalData} object if possible
       *
       * @param json The JSON to convert
       */
    static fromJson(json: string): AdditionalData;
    /**
       * Check if this data collection is empty or not.
       *
       * @return True if there are no data, false otherwise.
       */
    isEmpty(): boolean;
    /**
       * Add any arbitrary non-primitive object as value with an associated string based key.
       *
       * This will overwrite any previous values with the same key. Clients need to call [[hasData]] to check whether a key already
       * exists to avoid potential overwriting of existing values.
       *
       * Note that JsonOption is used here to store the type of the class so that it can be deserialised in higher level languages such as Java.
       *
       * @param key    The string key for this value
       * @param value The value to store
       */
    addData(key: string, value: any | JsonOption): void;
    /**
       * Copy over values from the provided AdditionalData model.
       *
       * Depending on the allowOverwrite parameter, existing values may or may not get overwritten.
       *
       * @param additionalData The data to copy from.
       * @param allowOverwrite Whether or not to allow overwriting existing values
       */
    addAdditionalData(additionalData: AdditionalData, allowOverwrite: boolean): void;
    /**
       * Remove data with associated key from the collection.
       *
       * @param key The data key
       *
       * @returns The value of the key removed
       */
    removeData(key: string): any;
    /**
       * Clear all data from the collection.
       */
    clearData(): void;
    /**
       * Check whether there is any data with the associated key in the collection.
       *
       * @param key The data key
       * @return True if exists, false otherwise.
       */
    hasData(key: string): boolean;
    /**
       * Get a set of all the keys for this data collection.
       *
       * @return An array of data keys
       */
    getKeys(): string[];
    protected getJsonOption(key: string): JsonOption | undefined;
    /**
       * Retrieve the value for the provided key as an object of type T.
       *
       * @param key          The data key
       * @param defaultValue Optional var-args where a default value can be passed in which will be returned if key does not exist
       * @return The value as an Object of type T or default value if set, or undefined
       */
    getValue<T extends object>(key: string, classReference?: {
        new (): T;
    }, defaultValue?: T): T | undefined;
}
