"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var AdditionalData_1;
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const json2typescript_1 = require("json2typescript");
const json_option_1 = require("../util/json-option");
const jsonable_1 = require("./jsonable");
let AdditionalDataConverter = class AdditionalDataConverter {
    serialize(data) {
        return data;
    }
    deserialize(dataValue) {
        const data = {};
        for (const key of Object.keys(dataValue)) {
            data[key] = json_option_1.JsonOption.from(dataValue[key].value, dataValue[key].type);
        }
        return data;
    }
};
AdditionalDataConverter = __decorate([
    json2typescript_1.JsonConverter
], AdditionalDataConverter);
let AdditionalData = AdditionalData_1 = class AdditionalData extends jsonable_1.Jsonable {
    constructor() {
        super(...arguments);
        this.data = {};
    }
    /**
       * Convert a JSON string into an {@link AdditionalData} object if possible
       *
       * @param json The JSON to convert
       */
    static fromJson(json) {
        return jsonable_1.Jsonable.baseFromJson(json, AdditionalData_1);
    }
    /**
       * Check if this data collection is empty or not.
       *
       * @return True if there are no data, false otherwise.
       */
    isEmpty() {
        return Object.keys(this.data).length === 0;
    }
    /**
       * Add any arbitrary non-primitive object as value with an associated string based key.
       *
       * This will overwrite any previous values with the same key. Clients need to call [[hasData]] to check whether a key already
       * exists to avoid potential overwriting of existing values.
       *
       * Note that JsonOption is used here to store the type of the class so that it can be deserialised in higher level languages such as Java.
       *
       * @param key    The string key for this value
       * @param value The value to store
       */
    addData(key, value) {
        if (value instanceof json_option_1.JsonOption) {
            this.data[key] = value;
        }
        else if (Array.isArray(value)) {
            if (value.length === 1) {
                this.data[key] = json_option_1.JsonOption.from(value[0]);
            }
            else {
                this.data[key] = json_option_1.JsonOption.from(value, 'array');
            }
        }
        else {
            this.data[key] = json_option_1.JsonOption.from(value);
        }
    }
    /**
       * Copy over values from the provided AdditionalData model.
       *
       * Depending on the allowOverwrite parameter, existing values may or may not get overwritten.
       *
       * @param additionalData The data to copy from.
       * @param allowOverwrite Whether or not to allow overwriting existing values
       */
    addAdditionalData(additionalData, allowOverwrite) {
        for (const key of additionalData.getKeys()) {
            if (allowOverwrite || !this.hasData(key)) {
                const val = additionalData.getJsonOption(key);
                if (val !== undefined) {
                    this.addData(key, val);
                }
            }
        }
    }
    /**
       * Remove data with associated key from the collection.
       *
       * @param key The data key
       *
       * @returns The value of the key removed
       */
    removeData(key) {
        const retVal = this.data[key];
        delete this.data[key];
        return retVal;
    }
    /**
       * Clear all data from the collection.
       */
    clearData() {
        this.data = {};
    }
    /**
       * Check whether there is any data with the associated key in the collection.
       *
       * @param key The data key
       * @return True if exists, false otherwise.
       */
    hasData(key) {
        return this.data[key] != null;
    }
    /**
       * Get a set of all the keys for this data collection.
       *
       * @return An array of data keys
       */
    getKeys() {
        return Object.keys(this.data);
    }
    getJsonOption(key) {
        return this.data[key];
    }
    /**
       * Retrieve the value for the provided key as an object of type T.
       *
       * @param key          The data key
       * @param defaultValue Optional var-args where a default value can be passed in which will be returned if key does not exist
       * @return The value as an Object of type T or default value if set, or undefined
       */
    getValue(key, classReference, defaultValue) {
        const option = this.data[key];
        if (option) {
            if (json_option_1.JsonOption.isPrimative(option.type) || !classReference) {
                return option.value;
            }
            return jsonable_1.Jsonable.baseFromJsonObject(option.value, classReference);
        }
        return defaultValue;
    }
};
__decorate([
    json2typescript_1.JsonProperty('data', AdditionalDataConverter),
    __metadata("design:type", Object)
], AdditionalData.prototype, "data", void 0);
AdditionalData = AdditionalData_1 = __decorate([
    json2typescript_1.JsonObject('AdditionalData')
], AdditionalData);
exports.AdditionalData = AdditionalData;
