import { FlowStage } from './flow-stage';
import { FlowApp } from './flow-app';
export declare class FlowConfig {
    name: string;
    type: string;
    version: number;
    apiMajorVersion: number;
    description?: string;
    restrictedToApp: string;
    stages: Array<FlowStage>;
    processInBackground: boolean;
    generatedFromCustomType: boolean;
    private allStagesFlattened;
    private allStagesMap;
    constructor();
    private parseStageHierarchy;
    private getDeepStages;
    static fromJson(json: string): FlowConfig;
    static from(name: string, type: string, version: number, apiMajorVersion: number, description: string, restrictedToApp: string, stages?: Array<FlowStage>, processInBackground?: boolean): FlowConfig;
    /**
       * Check whether this flow has an app restriction defined or not.
       *
       * If there is an app restriction defined, this can be used to filter out configurations that should only be allowed for a certain client application.
       *
       * @return True if there is a filter, false otherwise
       */
    hasAppRestriction(): boolean;
    /**
       * Verify whether a client app is allowed to read/initiate this flow configuration.
       *
       * @param clientPackageName The package name of the client application
       * @return True if the client app is allowed, false otherwise
       */
    isClientAppAllowed(clientPackageName: string): boolean;
    /**
       * Get the stages for this flow.
       *
       * As stages can be nested (a stage can have an inner flow), the returned list can either be top level only or all stages flattened.
       *
       * @param flattened Set to true to get all the stages (top level and nested) in the returned list, or false if just to get top level
       * @return The stages for this flow
       */
    getStages(flattened: boolean): Array<FlowStage>;
    /**
       * Get the request class for this flow, which indicates what type of request to use with it.
       *
       * If this flow is to be used by a {@link com.aevi.sdk.flow.model.Request}, then the return value will be [[REQUEST_CLASS_GENERIC]]
       *
       * If this flow is to be used for a payment initiation, then the return value will be [[REQUEST_CLASS_PAYMENT]]
       *
       * @return The request class for this flow
       */
    getRequestClass(): string;
    getAllStageNames(): Array<string>;
    getStage(stageName: string): FlowStage;
    hasStage(stage: string): boolean;
    hasAppForStage(stage: string, appId?: string): boolean;
    getAppsForStage(stageName: string): Array<FlowApp>;
    getFirstAppForStage(stageName: string): FlowApp;
    containsApp(flowAppId: string): boolean;
    getFlowApp(stage: string, appId: string): FlowApp;
    private findAppInList;
    private scanAppList;
    private normaliseStageName;
    setApps(stage: string, flowApps: Array<FlowApp>): void;
}
