import { Observable } from 'rxjs';
import { FlowConfig } from './flow-config';
export declare class FlowConfigurations {
    flowConfigurations: Array<FlowConfig>;
    /**
       * Get the flow configuration with the provided name.
       *
       * @param flowName The flow name
       * @return The flow config
       */
    getFlowConfiguration(flowName: string): FlowConfig;
    /**
       * Stream the list of flow configurations for simple filtering, conversions, etc.
       *
       * @return An Observable stream of {@link FlowConfig}
       */
    stream(): Observable<FlowConfig>;
    /**
       * Get supported flow types for the given request class.
       *
       * If this should return flow types for initiating generic {@link com.aevi.sdk.flow.model.Request}, then use {@link FlowConfig#REQUEST_CLASS_GENERIC}
       *
       * If this should return flow types for initiating {@link com.aevi.sdk.pos.flow.model.Payment}, then use {@link FlowConfig#REQUEST_CLASS_PAYMENT}
       *
       * If null is passed, all types will be returned.
       *
       * @param requestClass {@link FlowConfig#REQUEST_CLASS_GENERIC}, {@link FlowConfig#REQUEST_CLASS_PAYMENT} or null for all types
       * @return A list of supported flow types
       */
    getFlowTypes(requestClass: string): Array<string>;
    /**
       * Check whether a flow type is supported or not.
       *
       * A flow type is defined as supported if there is at least one flow configuration defined for that type.
       *
       * @param type The flow type to check
       * @return True if there is at least one flow for this type, false otherwise
       */
    isFlowTypeSupported(type: string): boolean;
    /**
       * Get a list of all the flow names that are associated with the provided types.
       *
       * @param typesArray The types to filter by
       * @return The list of flow names
       */
    getFlowNamesForType(...typesArray: Array<string>): Array<string>;
    /**
       * Get a list of all the flow configs that are associated with the provided types.
       *
       * @param typesArray The types to filter by
       * @return The list of flow names
       */
    getFlowConfigsForType(...typesArray: Array<string>): Array<FlowConfig>;
    /**
       * Check whether a particular flow has the provided stage defined.
       *
       * @param stage    The flow stage
       * @param flowName The flow to check if the stage is defined for
       * @return True if the flow has the stage defined, false otherwise
       */
    isStageDefinedForFlow(stage: string, flowName: string): boolean;
    private fromName;
}
