"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var PaymentSettings_1;
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const json2typescript_1 = require("json2typescript");
const additional_data_1 = require("../additional-data");
const payment_flow_services_1 = require("../payment-flow-services");
const flow_configurations_1 = require("./flow-configurations");
const fps_settings_1 = require("./fps-settings");
const app_flow_settings_1 = require("./app-flow-settings");
const flow_stage_1 = require("./flow-stage");
const jsonable_1 = require("../jsonable");
let PaymentSettings = PaymentSettings_1 = class PaymentSettings {
    constructor() {
        this.flowConfigurations = undefined;
        this.allServices = undefined;
        this.fpsSettings = undefined;
        this.appFlowSettings = undefined;
        this.additionalSettings = new additional_data_1.AdditionalData();
    }
    /**
       * Get an instance of {@link PaymentFlowServices} that contains a filtered list of services based on the provided flow configuration.
       *
       * This can be used to ensure that you retrieve the correct set of supported currencies, payment methods, etc based on the flow that
       * will be processed.
       *
       * If no applications are defined in the flow config, it is assumed any is eligible and the full list of services will be returned.
       *
       * If there is no flow by the provided name, all services will be returned.
       *
       * @param flowName The name of the flow configuration to filter services by
       * @return An instance of {@link PaymentFlowServices} with filtered set of services, or null if no flow config found
       */
    getServicesForFlow(flowName) {
        const flowConfig = this.flowConfigurations.getFlowConfiguration(flowName);
        if (flowConfig == null) {
            return this.allServices;
        }
        const paymentFlowServices = new Array();
        for (const flowStage of flowConfig.getStages(true)) {
            if (flowStage.appExecutionType !== flow_stage_1.AppExecutionType.NONE && flowStage.flowApps.length !== 0) {
                for (const flowApp of flowStage.flowApps) {
                    const flowServiceFromId = this.allServices.getFlowServiceFromId(flowApp.id);
                    if (flowServiceFromId != null) {
                        paymentFlowServices.push(flowServiceFromId);
                    }
                }
            }
        }
        if (paymentFlowServices.length > 0) {
            return payment_flow_services_1.PaymentFlowServices.from(paymentFlowServices);
        }
        return this.allServices;
    }
    static fromJson(json) {
        return jsonable_1.Jsonable.baseFromJson(json, PaymentSettings_1);
    }
};
__decorate([
    json2typescript_1.JsonProperty('flowConfigurations', flow_configurations_1.FlowConfigurations),
    __metadata("design:type", flow_configurations_1.FlowConfigurations)
], PaymentSettings.prototype, "flowConfigurations", void 0);
__decorate([
    json2typescript_1.JsonProperty('allServices', payment_flow_services_1.PaymentFlowServices),
    __metadata("design:type", payment_flow_services_1.PaymentFlowServices)
], PaymentSettings.prototype, "allServices", void 0);
__decorate([
    json2typescript_1.JsonProperty('fpsSettings', fps_settings_1.FpsSettings),
    __metadata("design:type", fps_settings_1.FpsSettings)
], PaymentSettings.prototype, "fpsSettings", void 0);
__decorate([
    json2typescript_1.JsonProperty('appFlowSettings', app_flow_settings_1.AppFlowSettings),
    __metadata("design:type", app_flow_settings_1.AppFlowSettings)
], PaymentSettings.prototype, "appFlowSettings", void 0);
__decorate([
    json2typescript_1.JsonProperty('additionalSettings', additional_data_1.AdditionalData),
    __metadata("design:type", additional_data_1.AdditionalData)
], PaymentSettings.prototype, "additionalSettings", void 0);
PaymentSettings = PaymentSettings_1 = __decorate([
    json2typescript_1.JsonObject('PaymentSettings')
], PaymentSettings);
exports.PaymentSettings = PaymentSettings;
