"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var Customer_1;
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const json2typescript_1 = require("json2typescript");
const uuid_1 = require("uuid");
const additional_data_1 = require("./additional-data");
const token_1 = require("./token");
const jsonable_1 = require("./jsonable");
var CustomerDataKeys;
(function (CustomerDataKeys) {
    CustomerDataKeys["FIRST_NAME"] = "firstName";
    CustomerDataKeys["SURNAME"] = "surname";
    CustomerDataKeys["MIDDLE_NAMES"] = "middleNames";
    CustomerDataKeys["PHONE"] = "phone";
    CustomerDataKeys["EMAIL"] = "email";
    CustomerDataKeys["ADDRESS"] = "address";
    CustomerDataKeys["POSTCODE"] = "postcode";
    CustomerDataKeys["CITY"] = "city";
    CustomerDataKeys["STATE"] = "state";
    CustomerDataKeys["COUNTRY"] = "country";
})(CustomerDataKeys = exports.CustomerDataKeys || (exports.CustomerDataKeys = {}));
/**
 * Represents a paying customer with associated customer details and tokens.
 */
let Customer = Customer_1 = class Customer extends jsonable_1.Jsonable {
    constructor() {
        super();
        this.id = undefined;
        this.fullName = undefined;
        this.customerDetails = new additional_data_1.AdditionalData();
        this.tokens = [];
        this.id = uuid_1.v4();
    }
    /**
       * Creates and returns a new Customer object based on the details given
       *
       * @param id The unique Id of the customer
       * @param fullName The customers full name
       * @param customerDetails Any other details to be associated with this customer see {@link CustomerDataKeys} for keys
       * @param tokens Any tokens that should be associated with this customer
       *
       * @returns The new Customer object
       */
    static from(id, fullName, customerDetails, tokens) {
        const c = new Customer_1();
        c.id = id;
        c.fullName = fullName;
        if (customerDetails) {
            c.customerDetails = customerDetails;
        }
        if (tokens) {
            c.tokens = tokens;
        }
        return c;
    }
    /**
       * Convert a JSON string into an {@link Customer} object if possible
       *
       * @param json The JSON to convert
       */
    static fromJson(json) {
        return jsonable_1.Jsonable.baseFromJson(json, Customer_1);
    }
    /**
       * Convenience wrapper for adding additional customer data.
       *
       * This can be used to set arbitrary data to be passed on in the request to down-stream flow apps and/or payment apps.
       *
       * See {@link AdditionalData#addData(String, Object[])} for more info.
       *
       * @param key    The key to use for this data
       * @param values An array of values for this data
       */
    addCustomerDetails(key, ...values) {
        this.customerDetails.addData(key, values);
    }
};
__decorate([
    json2typescript_1.JsonProperty('id'),
    __metadata("design:type", String)
], Customer.prototype, "id", void 0);
__decorate([
    json2typescript_1.JsonProperty('fullName'),
    __metadata("design:type", String)
], Customer.prototype, "fullName", void 0);
__decorate([
    json2typescript_1.JsonProperty('customerDetails', additional_data_1.AdditionalData),
    __metadata("design:type", additional_data_1.AdditionalData)
], Customer.prototype, "customerDetails", void 0);
__decorate([
    json2typescript_1.JsonProperty('tokens', [token_1.Token]),
    __metadata("design:type", Array)
], Customer.prototype, "tokens", void 0);
Customer = Customer_1 = __decorate([
    json2typescript_1.JsonObject('Customer'),
    __metadata("design:paramtypes", [])
], Customer);
exports.Customer = Customer;
