"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var Device_1;
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const json2typescript_1 = require("json2typescript");
const additional_data_1 = require("./additional-data");
const jsonable_1 = require("./jsonable");
var DeviceDataKeys;
(function (DeviceDataKeys) {
    DeviceDataKeys["MANUFACTURER"] = "maufacturer";
    DeviceDataKeys["MODEL"] = "model";
    DeviceDataKeys["SERIAL"] = "serial";
})(DeviceDataKeys = exports.DeviceDataKeys || (exports.DeviceDataKeys = {}));
/**
 * Represents a device.
 */
let Device = Device_1 = class Device extends jsonable_1.Jsonable {
    constructor() {
        super(...arguments);
        this.referenceId = undefined;
        this.serialNumber = undefined;
        this.model = undefined;
        this.name = undefined;
        this.location = undefined;
        this.details = new additional_data_1.AdditionalData();
    }
    /**
       * Creates and returns a new Device object based on the details given
       *
       * @param referenceId The unique Id of the device
       * @param name The friendly name of the device
       * @param details Any other details to be associated with this device e,g, make and model etc see {@link DeviceDataKeys}
       *
       * @returns The new Customer object
       */
    static from(referenceId, name, details) {
        const device = new Device_1();
        device.referenceId = referenceId;
        device.name = name;
        if (details) {
            device.details = details;
        }
        return device;
    }
    /**
       * Convert a JSON string into an {@link Device} object if possible
       *
       * @param json The JSON to convert
       */
    static fromJson(json) {
        return jsonable_1.Jsonable.baseFromJson(json, Device_1);
    }
};
__decorate([
    json2typescript_1.JsonProperty('referenceId'),
    __metadata("design:type", String)
], Device.prototype, "referenceId", void 0);
__decorate([
    json2typescript_1.JsonProperty('serialNumber'),
    __metadata("design:type", String)
], Device.prototype, "serialNumber", void 0);
__decorate([
    json2typescript_1.JsonProperty('model'),
    __metadata("design:type", String)
], Device.prototype, "model", void 0);
__decorate([
    json2typescript_1.JsonProperty('name', String, true),
    __metadata("design:type", String)
], Device.prototype, "name", void 0);
__decorate([
    json2typescript_1.JsonProperty('location', String, true),
    __metadata("design:type", String)
], Device.prototype, "location", void 0);
__decorate([
    json2typescript_1.JsonProperty('details', additional_data_1.AdditionalData, true),
    __metadata("design:type", additional_data_1.AdditionalData)
], Device.prototype, "details", void 0);
Device = Device_1 = __decorate([
    json2typescript_1.JsonObject('Device')
], Device);
exports.Device = Device;
