"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var Merchant_1;
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const json2typescript_1 = require("json2typescript");
const jsonable_1 = require("./jsonable");
const additional_data_1 = require("./additional-data");
var MerchantDataKeys;
(function (MerchantDataKeys) {
    MerchantDataKeys["NAME"] = "name";
    MerchantDataKeys["PHONE"] = "phone";
    MerchantDataKeys["EMAIL"] = "email";
    MerchantDataKeys["ADDRESS"] = "address";
    MerchantDataKeys["POSTCODE"] = "postcode";
    MerchantDataKeys["CITY"] = "city";
    MerchantDataKeys["STATE"] = "state";
    MerchantDataKeys["COUNTRY"] = "country";
})(MerchantDataKeys = exports.MerchantDataKeys || (exports.MerchantDataKeys = {}));
var MerchantTokenKeys;
(function (MerchantTokenKeys) {
    MerchantTokenKeys["MARKETPLACE"] = "marketplace";
    MerchantTokenKeys["AEVIPAY"] = "aevipay";
    MerchantTokenKeys["UMP"] = "ump";
})(MerchantTokenKeys = exports.MerchantTokenKeys || (exports.MerchantTokenKeys = {}));
/**
 * A model to store merchant data such as address and contact details
 */
let Merchant = Merchant_1 = class Merchant extends jsonable_1.Jsonable {
    constructor() {
        super(...arguments);
        this.umpId = undefined;
        this.name = undefined;
        this.details = new additional_data_1.AdditionalData();
        this.tokens = new additional_data_1.AdditionalData();
    }
    /**
       * Create a new merchant object using the details given
       *
       * @param umpId The unique Unified Merchant Portal (UMP) id of this merchant
       * @param name The name of the merchant
       * @param details All other details for this merchant stored as a
       * @param tokens A collection of {@link Token} objects that give this merchant access to the various external services
       */
    static from(umpId, name, details, tokens) {
        const merch = new Merchant_1();
        merch.umpId = umpId;
        merch.name = name;
        if (details) {
            merch.details = details;
        }
        if (tokens) {
            merch.tokens = tokens;
        }
        return merch;
    }
    /**
       * Convert a JSON string into an {@link Merchant} object if possible
       *
       * @param json The JSON to convert
       */
    static fromJson(json) {
        return jsonable_1.Jsonable.baseFromJson(json, Merchant_1);
    }
    /**
       * Convenience wrapper for adding additional merchant data.
       *     *
       * See {@link AdditionalData#addData(String, Object[])} for more info.
       *
       * @param key    The key to use for this data
       * @param values An array of values for this data
       */
    addMerchantDetails(key, ...values) {
        this.details.addData(key, values);
    }
};
__decorate([
    json2typescript_1.JsonProperty('umpId'),
    __metadata("design:type", String)
], Merchant.prototype, "umpId", void 0);
__decorate([
    json2typescript_1.JsonProperty('name'),
    __metadata("design:type", String)
], Merchant.prototype, "name", void 0);
__decorate([
    json2typescript_1.JsonProperty('merchantDetails', additional_data_1.AdditionalData),
    __metadata("design:type", additional_data_1.AdditionalData)
], Merchant.prototype, "details", void 0);
__decorate([
    json2typescript_1.JsonProperty('tokens', additional_data_1.AdditionalData),
    __metadata("design:type", additional_data_1.AdditionalData)
], Merchant.prototype, "tokens", void 0);
Merchant = Merchant_1 = __decorate([
    json2typescript_1.JsonObject('Merchant')
], Merchant);
exports.Merchant = Merchant;
