"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var Payment_1;
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const json2typescript_1 = require("json2typescript");
const uuid_1 = require("uuid");
const amounts_1 = require("./amounts");
const basket_1 = require("./basket");
const customer_1 = require("./customer");
const token_1 = require("./token");
const additional_data_1 = require("./additional-data");
const jsonable_1 = require("./jsonable");
var FlowTypes;
(function (FlowTypes) {
    FlowTypes["sale"] = "sale";
    FlowTypes["refund"] = "refund";
    FlowTypes["motoSale"] = "motoSale";
    FlowTypes["motoRefund"] = "motoRefund";
    FlowTypes["preAuthorisation"] = "preAuthorisation";
    FlowTypes["preAuthCompletion"] = "preAuthCompletion";
    FlowTypes["deposit"] = "deposit";
    FlowTypes["reversal"] = "reversal";
    FlowTypes["tokenisation"] = "tokenisation";
    FlowTypes["batchClosure"] = "batchClosure";
    FlowTypes["receiptDelivery"] = "receiptDelivery";
})(FlowTypes = exports.FlowTypes || (exports.FlowTypes = {}));
/**
 * Payment model containing relevant information for initiating payments involving amounts.
 *
 * For other type of requests (such as reversals), please see {@link Request}
 */
let Payment = Payment_1 = class Payment extends jsonable_1.Jsonable {
    constructor() {
        super();
        this.id = undefined;
        this.flowType = undefined;
        this.flowName = undefined;
        this.amounts = undefined;
        this.paymentMethod = undefined;
        this.basket = undefined;
        this.customer = undefined;
        this.splitEnabled = false;
        this.cardToken = undefined;
        this.additionalData = new additional_data_1.AdditionalData();
        this.isExternalId = false;
        this.source = undefined;
        this.deviceId = undefined;
        this.id = uuid_1.v4();
    }
    /**
       * Convert a JSON string into an {@link Payment} object if possible
       *
       * @param json The JSON to convert
       *
       * @returns A Payment object
       */
    static fromJson(json) {
        return super.baseFromJson(json, Payment_1);
    }
};
__decorate([
    json2typescript_1.JsonProperty('id'),
    __metadata("design:type", String)
], Payment.prototype, "id", void 0);
__decorate([
    json2typescript_1.JsonProperty('flowType'),
    __metadata("design:type", String)
], Payment.prototype, "flowType", void 0);
__decorate([
    json2typescript_1.JsonProperty('flowName', String, true),
    __metadata("design:type", String)
], Payment.prototype, "flowName", void 0);
__decorate([
    json2typescript_1.JsonProperty('amounts', amounts_1.Amounts),
    __metadata("design:type", amounts_1.Amounts)
], Payment.prototype, "amounts", void 0);
__decorate([
    json2typescript_1.JsonProperty('paymentMethod', String, true),
    __metadata("design:type", String)
], Payment.prototype, "paymentMethod", void 0);
__decorate([
    json2typescript_1.JsonProperty('basket', basket_1.Basket, true),
    __metadata("design:type", basket_1.Basket)
], Payment.prototype, "basket", void 0);
__decorate([
    json2typescript_1.JsonProperty('customer', customer_1.Customer, true),
    __metadata("design:type", customer_1.Customer)
], Payment.prototype, "customer", void 0);
__decorate([
    json2typescript_1.JsonProperty('splitEnabled', Boolean, true),
    __metadata("design:type", Boolean)
], Payment.prototype, "splitEnabled", void 0);
__decorate([
    json2typescript_1.JsonProperty('cardToken', token_1.Token, true),
    __metadata("design:type", token_1.Token)
], Payment.prototype, "cardToken", void 0);
__decorate([
    json2typescript_1.JsonProperty('additionalData', additional_data_1.AdditionalData),
    __metadata("design:type", additional_data_1.AdditionalData)
], Payment.prototype, "additionalData", void 0);
__decorate([
    json2typescript_1.JsonProperty('isExternalId', Boolean, true),
    __metadata("design:type", Boolean)
], Payment.prototype, "isExternalId", void 0);
__decorate([
    json2typescript_1.JsonProperty('source', String, true),
    __metadata("design:type", String)
], Payment.prototype, "source", void 0);
__decorate([
    json2typescript_1.JsonProperty('deviceId', String, true),
    __metadata("design:type", String)
], Payment.prototype, "deviceId", void 0);
Payment = Payment_1 = __decorate([
    json2typescript_1.JsonObject('Payment'),
    __metadata("design:paramtypes", [])
], Payment);
exports.Payment = Payment;
