import { ResponseQuery } from './response-query';
export declare class ResponseQueryBuilder {
    flowName: string;
    flowType: string;
    startDate: number;
    endDate: number;
    maxResults: number;
    requestId: string;
    /**
       * Optionally restrict this query to responses for the given flow name
       *
       * @param flowName The flow name to restrict to
       * @return this builder
       */
    withFlowName(flowName: string): ResponseQueryBuilder;
    /**
       * Optionally restrict this query to responses for the given flow type
       *
       * @param flowType The flow type to restrict to
       * @return this builder
       */
    withFlowType(flowType: string): ResponseQueryBuilder;
    /**
       * Optionally restrict this query to responses within a given date range
       *
       * The start date is the earliest date to search for and the end date is the latest. Both times are in milliseconds since epoch.
       *
       * Both parameters must be set and the startDate must be less than the endDate
       *
       * @param startDate The earliest date to collect responses for
       * @param endDate   The last date to collect responses for
       * @return this builder
       */
    withDateRange(startDate: number, endDate: number): ResponseQueryBuilder;
    /**
       * Optionally restrict this query to a specific requestId
       *
       * If this is set all other parameters set in this builder will be ignored
       *
       * @param requestId The requestId restrict to
       * @return this builder
       */
    withRequestId(requestId: string): ResponseQueryBuilder;
    /**
       * This field can be used to change the number of results returned in this query. By default it is set to a maximum of 100
       *
       * @param maxResults The maximum number of responses to return
       * @return this builder
       */
    withMaxResults(maxResults: number): ResponseQueryBuilder;
    build(): ResponseQuery;
}
