import { BasketItemModifier } from './basket-item-modifier';
/**
 * A builder to create {@link BasketItemModifier} instances
 */
export declare class BasketItemModifierBuilder {
    readonly name: string;
    readonly type: string;
    private id;
    private amount;
    private percentage;
    /**
       * Create an instance of this builder
       *
       * @param name The name of the modifier you are building
       * @param type The type of modifier you are building
       */
    constructor(name: string, type: string);
    /**
       * Set the id for this item modifier (optional).
       *
       * @param id The id
       * @return This builder
       */
    withId(id: string): BasketItemModifierBuilder;
    /**
       * Set the absolute amount of this modifier in subunit form (e.g pence / cents). This amount may be fractional i.e. fractions of one cent/penny.
       * A fractional value may used in cases such as representing a tax amount that needs to be correct to several decimal places of accuracy when
       * these item modifiers are added together as a part of a whole transaction. If a fractional value is not required then use
       * {@link BasketItemModifierBuilder#withAmount(long)} instead.
       *
       * This value can be negative to indicate a reduction/discount to the item amount.
       *
       * @param amount The amount
       * @return This builder
       */
    withAmount(amount: number): BasketItemModifierBuilder;
    /**
       * Set the percentage rate for this modifier.
       *
       * The percentage is represented as a float value, such as 25.75 for 25.75%.
       *
       * This value can be negative to indicate a reduction/discount to the item amount.
       *
       * @param percentage The percentage
       * @return This builder
       */
    withPercentage(percentage: number): BasketItemModifierBuilder;
    /**
       * Build the modifier instance.
       *
       * As well as name and type either an absolute amount or a percentage must also be set otherwise this method will throw an {@link IllegalArgumentException}.
       *
       * @return A {@link BasketItemModifier} instance
       */
    build(): BasketItemModifier;
}
