"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var BasketItemModifier_1;
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const json2typescript_1 = require("json2typescript");
const pre_conditions_1 = require("../util/pre-conditions");
/**
 * A {@link BasketItemModifier} can be used to associate additional cost/amounts with a basket item, such as tax, discounts or add-ons.
 *
 * Either an absolute amount or a percentage must be set.
 */
let BasketItemModifier = BasketItemModifier_1 = class BasketItemModifier {
    constructor() {
        this.id = undefined;
        this.name = undefined;
        this.type = undefined;
        this.amount = undefined;
        this.percentage = undefined;
    }
    /**
       * Create an instance of a modifier.
       *
       * Either an absolute amount or a percentage must be set.
       *
       * @param id         The id, if one exists. May be null
       * @param name       The name of the modifier.
       * @param type       The type of the modifier.
       * @param amount     The absolute amount of the modifier.
       * @param percentage The percentage applied to the item amounts.
       *
       * @returns The new BaskeTItemModifier instance
       */
    static from(name, type, amount, percentage, id) {
        pre_conditions_1.PreConditions.checkArgument(amount != null || percentage != null, 'Either amount or percentage must be set');
        const bim = new BasketItemModifier_1();
        bim.name = name;
        bim.type = type;
        bim.amount = amount;
        bim.percentage = percentage;
        bim.id = id;
        return bim;
    }
};
__decorate([
    json2typescript_1.JsonProperty('id', String, true),
    __metadata("design:type", String)
], BasketItemModifier.prototype, "id", void 0);
__decorate([
    json2typescript_1.JsonProperty('name'),
    __metadata("design:type", String)
], BasketItemModifier.prototype, "name", void 0);
__decorate([
    json2typescript_1.JsonProperty('type'),
    __metadata("design:type", String)
], BasketItemModifier.prototype, "type", void 0);
__decorate([
    json2typescript_1.JsonProperty('amount', Number, true),
    __metadata("design:type", Number)
], BasketItemModifier.prototype, "amount", void 0);
__decorate([
    json2typescript_1.JsonProperty('percentage', Number, true),
    __metadata("design:type", Number)
], BasketItemModifier.prototype, "percentage", void 0);
BasketItemModifier = BasketItemModifier_1 = __decorate([
    json2typescript_1.JsonObject('BasketItemModifier')
], BasketItemModifier);
exports.BasketItemModifier = BasketItemModifier;
