import { AdditionalData } from './additional-data';
import { Token } from './token';
/**
 * The card details representing the card presented during a transaction.
 *
 * All fields in this class are optional and the payment service used may or may not return all these values.
 */
export declare class Card {
    private static MAX_PAN_DIGITS_ALLOWED;
    maskedPan?: string;
    cardholderName?: string;
    expiryDate?: string;
    cardToken?: Token;
    additionalData: AdditionalData;
    /**
       * Check whether this object contains any card data.
       *
       * @return True if empty, false if contains data
       */
    isEmpty(): boolean;
    /**
       * Create and returns a new Card object from the parameters given
       *
       * @param maskedPan The masked PAN of the card
       * @param cardholderName The cardholder name from the card
       * @param expiryDate The expiry date of the card in the format YYMM
       * @param token The token associated with this card
       * @param additionalData Optionally any other additional card data such as EMV data etc.
       *
       * @returns The newly created Card object
       */
    static from(maskedPan: string, cardholderName: string, expiryDate: string, token: Token, additionalData?: AdditionalData): Card;
    /**
       * Get the expiry date formatted as per the provided pattern.
       *
       * See Java SimpleDateFormat for pattern documentation.
       *
       * @param pattern The moment.js pattern to format the expiry date as
       * @return The formatted expiry date, or null if expiry date not set or pattern is invalid
       */
    getFormattedExpiryDate(pattern: string): string;
}
