"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const card_1 = require("./card");
const pre_conditions_1 = require("../util/pre-conditions");
const additional_data_1 = require("./additional-data");
describe('Card', () => {
    it('should create an instance', () => {
        expect(new card_1.Card()).toBeTruthy();
    });
    it('should not allow pan with more than 10 digits', () => {
        expect(() => { card_1.Card.from('1234567890123456', 'Mr T', '0102', null, null); }).toThrowError(pre_conditions_1.InvalidArgumentError);
    });
    it('should allow pan with less than 10 digits', () => {
        const card = card_1.Card.from('123456789XXXXXX', 'Mr T', '0102', null, null);
        expect(card.maskedPan).toBe('123456789XXXXXX');
    });
    it('should format expiry date correctly', () => {
        const card = card_1.Card.from('123456789XXXXXX', 'Mr T', '2210', null, null);
        expect(card.getFormattedExpiryDate('MM/YYYY')).toBe('10/2022');
    });
    it('should return empty when its empty', () => {
        const card = new card_1.Card();
        expect(card.isEmpty()).toBeTruthy();
        card.cardholderName = 'bob';
        expect(card.isEmpty()).toBeFalsy();
    });
    it('should return empty correctly when addtional data set', () => {
        const card = new card_1.Card();
        expect(card.isEmpty()).toBeTruthy();
        const ad = new additional_data_1.AdditionalData();
        ad.addData('ghost', 'boo');
        card.additionalData = ad;
        expect(card.isEmpty()).toBeFalsy();
    });
});
