"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var FlowConfig_1;
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const json2typescript_1 = require("json2typescript");
// eslint-disable-next-line import/no-cycle
const flow_stage_1 = require("./flow-stage");
const constants_1 = require("../constants");
const jsonable_1 = require("../jsonable");
const REQUEST_CLASS_GENERIC = 'generic';
const REQUEST_CLASS_PAYMENT = 'payment';
let FlowConfig = FlowConfig_1 = class FlowConfig {
    constructor() {
        this.name = undefined;
        this.type = undefined;
        this.version = undefined;
        this.apiMajorVersion = undefined;
        this.description = undefined;
        this.restrictedToApp = '';
        this.stages = [];
        this.processInBackground = false;
        this.generatedFromCustomType = false;
        this.parseStageHierarchy();
    }
    parseStageHierarchy() {
        this.allStagesFlattened = new Array();
        this.allStagesMap = new Map();
        this.getDeepStages(this.allStagesFlattened, this.stages);
    }
    getDeepStages(allStages, toAdd) {
        if (toAdd != null) {
            for (const stage of toAdd) {
                allStages.push(stage);
                this.allStagesMap.set(this.normaliseStageName(stage.name), stage);
                if (stage.hasInnerFlow()) {
                    this.getDeepStages(allStages, stage.innerFlow.getStages(false));
                }
            }
        }
    }
    static fromJson(json) {
        return jsonable_1.Jsonable.baseFromJson(json, FlowConfig_1);
    }
    static from(name, type, version, apiMajorVersion, description, restrictedToApp, stages, processInBackground) {
        const fc = new FlowConfig_1();
        fc.name = name;
        fc.type = type;
        fc.version = version;
        fc.apiMajorVersion = apiMajorVersion;
        fc.description = description;
        fc.restrictedToApp = restrictedToApp;
        if (stages) {
            fc.stages = stages;
        }
        if (processInBackground) {
            fc.processInBackground = processInBackground;
        }
        return fc;
    }
    /**
       * Check whether this flow has an app restriction defined or not.
       *
       * If there is an app restriction defined, this can be used to filter out configurations that should only be allowed for a certain client application.
       *
       * @return True if there is a filter, false otherwise
       */
    hasAppRestriction() {
        return this.restrictedToApp !== '';
    }
    /**
       * Verify whether a client app is allowed to read/initiate this flow configuration.
       *
       * @param clientPackageName The package name of the client application
       * @return True if the client app is allowed, false otherwise
       */
    isClientAppAllowed(clientPackageName) {
        return !this.hasAppRestriction() || this.restrictedToApp === clientPackageName;
    }
    /**
       * Get the stages for this flow.
       *
       * As stages can be nested (a stage can have an inner flow), the returned list can either be top level only or all stages flattened.
       *
       * @param flattened Set to true to get all the stages (top level and nested) in the returned list, or false if just to get top level
       * @return The stages for this flow
       */
    getStages(flattened) {
        return flattened ? this.allStagesFlattened : this.stages;
    }
    /**
       * Get the request class for this flow, which indicates what type of request to use with it.
       *
       * If this flow is to be used by a {@link com.aevi.sdk.flow.model.Request}, then the return value will be [[REQUEST_CLASS_GENERIC]]
       *
       * If this flow is to be used for a payment initiation, then the return value will be [[REQUEST_CLASS_PAYMENT]]
       *
       * @return The request class for this flow
       */
    getRequestClass() {
        return this.allStagesMap.has(this.normaliseStageName(constants_1.FlowStages.TRANSACTION_PROCESSING)) ? REQUEST_CLASS_PAYMENT : REQUEST_CLASS_GENERIC;
    }
    getAllStageNames() {
        return [...this.allStagesMap.keys()];
    }
    getStage(stageName) {
        return this.allStagesMap.get(this.normaliseStageName(stageName));
    }
    hasStage(stage) {
        return this.allStagesMap.has(this.normaliseStageName(stage));
    }
    hasAppForStage(stage, appId) {
        const normalisedStage = this.normaliseStageName(stage);
        if (appId) {
            return this.allStagesMap.has(normalisedStage) && this.scanAppList(this.allStagesMap.get(normalisedStage).flowApps, appId);
        }
        return this.allStagesMap.has(normalisedStage) && this.allStagesMap.get(normalisedStage).flowApps.length > 0;
    }
    getAppsForStage(stageName) {
        if (this.hasStage(stageName)) {
            return this.getStage(stageName).flowApps;
        }
        return [];
    }
    getFirstAppForStage(stageName) {
        if (this.hasStage(stageName)) {
            const apps = this.getAppsForStage(stageName);
            if (apps.length > 0) {
                return apps[0];
            }
        }
        return null;
    }
    containsApp(flowAppId) {
        let found = false;
        for (const stage of this.getStages(true)) {
            found = found || this.scanAppList(stage.flowApps, flowAppId);
        }
        return found;
    }
    getFlowApp(stage, appId) {
        const normalisedStage = this.normaliseStageName(stage);
        if (this.allStagesMap.has(normalisedStage)) {
            return this.findAppInList(this.allStagesMap.get(normalisedStage).flowApps, appId);
        }
        return null;
    }
    findAppInList(apps, appId) {
        if (apps != null) {
            for (const app of apps) {
                if (app.id === appId) {
                    return app;
                }
            }
        }
        return null;
    }
    scanAppList(apps, appId) {
        if (apps != null) {
            for (const app of apps) {
                if (app.id === appId) {
                    return true;
                }
            }
        }
        return false;
    }
    normaliseStageName(stage) {
        if (stage != null) {
            return stage.toUpperCase();
        }
        return null;
    }
    setApps(stage, flowApps) {
        const normalisedStage = this.normaliseStageName(stage);
        let flowStage = this.getStage(normalisedStage);
        if (flowStage == null) {
            flowStage = flow_stage_1.FlowStage.from(normalisedStage, flow_stage_1.AppExecutionType.MULTIPLE);
            flowStage.flowApps = flowApps;
            this.stages.push(flowStage);
            this.allStagesFlattened = null;
            this.allStagesMap = null;
            this.parseStageHierarchy();
        }
        else {
            flowStage.flowApps = flowApps;
        }
    }
};
__decorate([
    json2typescript_1.JsonProperty('name'),
    __metadata("design:type", String)
], FlowConfig.prototype, "name", void 0);
__decorate([
    json2typescript_1.JsonProperty('type'),
    __metadata("design:type", String)
], FlowConfig.prototype, "type", void 0);
__decorate([
    json2typescript_1.JsonProperty('version'),
    __metadata("design:type", Number)
], FlowConfig.prototype, "version", void 0);
__decorate([
    json2typescript_1.JsonProperty('apiMajorVersion'),
    __metadata("design:type", Number)
], FlowConfig.prototype, "apiMajorVersion", void 0);
__decorate([
    json2typescript_1.JsonProperty('description', String, true),
    __metadata("design:type", String)
], FlowConfig.prototype, "description", void 0);
__decorate([
    json2typescript_1.JsonProperty('restrictedToApp', String, true),
    __metadata("design:type", String)
], FlowConfig.prototype, "restrictedToApp", void 0);
__decorate([
    json2typescript_1.JsonProperty('stages', [flow_stage_1.FlowStage]),
    __metadata("design:type", Array)
], FlowConfig.prototype, "stages", void 0);
__decorate([
    json2typescript_1.JsonProperty('processInBackground'),
    __metadata("design:type", Boolean)
], FlowConfig.prototype, "processInBackground", void 0);
__decorate([
    json2typescript_1.JsonProperty('generatedFromCustomType'),
    __metadata("design:type", Boolean)
], FlowConfig.prototype, "generatedFromCustomType", void 0);
FlowConfig = FlowConfig_1 = __decorate([
    json2typescript_1.JsonObject('FlowConfig'),
    __metadata("design:paramtypes", [])
], FlowConfig);
exports.FlowConfig = FlowConfig;
