"use strict";
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
var AppMessageTypes;
(function (AppMessageTypes) {
    // Initiated by client apps
    AppMessageTypes["REQUEST_MESSAGE"] = "request";
    AppMessageTypes["PAYMENT_MESSAGE"] = "payment";
    AppMessageTypes["PAYMENT_FLOW_CONFIG_REQUEST"] = "paymentFlowConfigRequest";
    AppMessageTypes["RESPONSES_REQUEST"] = "responsesRequest";
    AppMessageTypes["DEVICE_INFO_REQUEST"] = "deviceInfoRequest";
    // Sent from flow services
    AppMessageTypes["RESPONSE_MESSAGE"] = "response";
    AppMessageTypes["AUDIT_ENTRY"] = "auditEntry";
    AppMessageTypes["FAILURE_MESSAGE"] = "failure";
    AppMessageTypes["REQUEST_ACK_MESSAGE"] = "requestAck";
    // Sent by FPS
    AppMessageTypes["FLOW_SERVICE_EVENT"] = "flowServiceEvent";
})(AppMessageTypes = exports.AppMessageTypes || (exports.AppMessageTypes = {}));
var ResponseMechanisms;
(function (ResponseMechanisms) {
    ResponseMechanisms["MESSENGER_CONNECTION"] = "messengerConnection";
    ResponseMechanisms["RESPONSE_SERVICE"] = "responseService";
})(ResponseMechanisms = exports.ResponseMechanisms || (exports.ResponseMechanisms = {}));
/**
 * Account type definitions representing possible account type choices for a payment card transaction.
 */
var AccountTypes;
(function (AccountTypes) {
    AccountTypes["ACCOUNT_TYPE_CREDIT"] = "credit";
    AccountTypes["ACCOUNT_TYPE_DEBIT"] = "debit";
    AccountTypes["ACCOUNT_TYPE_SAVINGS"] = "savings";
    AccountTypes["ACCOUNT_TYPE_PREPAID"] = "prepaid";
    AccountTypes["ACCOUNT_TYPE_CHEQUE"] = "cheque";
})(AccountTypes = exports.AccountTypes || (exports.AccountTypes = {}));
/**
 * General/common data keys used for various scenarios.
 */
var AdditionalDataKeys;
(function (AdditionalDataKeys) {
    AdditionalDataKeys["DATA_KEY_TRANSACTION"] = "transaction";
    AdditionalDataKeys["DATA_KEY_TRANSACTION_ID"] = "transactionId";
    AdditionalDataKeys["DATA_KEY_AMOUNTS"] = "amounts";
    AdditionalDataKeys["DATA_KEY_AMOUNT"] = "amount";
    AdditionalDataKeys["DATA_KEY_BASKET"] = "basket";
    AdditionalDataKeys["DATA_KEY_CUSTOMER"] = "customer";
    AdditionalDataKeys["DATA_KEY_TOKEN"] = "token";
    AdditionalDataKeys["DATA_KEY_TRANSACTION_LANGUAGE"] = "transactionLanguage";
    AdditionalDataKeys["DATA_KEY_ACCESSIBLE_MODE"] = "accessibleMode";
    AdditionalDataKeys["DATA_KEY_TAX_INFO"] = "taxInfo";
    AdditionalDataKeys["DATA_KEY_CARD"] = "card";
    AdditionalDataKeys["DATA_KEY_CURRENCY"] = "currency";
    /**
       * This key should be added to the additional data of a request if post auth tip adjustment is allowed
       */
    AdditionalDataKeys["DATA_KEY_POST_AUTH_TIP_ADJUST"] = "postAuthTipAdjust";
    AdditionalDataKeys["DATA_KEY_PAYMENT_SETTINGS"] = "paymentSettings";
})(AdditionalDataKeys = exports.AdditionalDataKeys || (exports.AdditionalDataKeys = {}));
/**
 * Identifiers to use for adding additional amounts.
 */
var AmountIdentifiers;
(function (AmountIdentifiers) {
    AmountIdentifiers["AMOUNT_TIP"] = "tip";
    AmountIdentifiers["AMOUNT_CASHBACK"] = "cashback";
    AmountIdentifiers["AMOUNT_SURCHARGE"] = "surcharge";
    AmountIdentifiers["AMOUNT_CHARITY_DONATION"] = "charityDonation";
})(AmountIdentifiers = exports.AmountIdentifiers || (exports.AmountIdentifiers = {}));
/**
 * Keys used to describe what type of data was augmented.
 */
var AugmentedDataKeys;
(function (AugmentedDataKeys) {
    AugmentedDataKeys["AUGMENTED_DATA_AMOUNTS"] = "amounts";
    AugmentedDataKeys["AUGMENTED_DATA_BASKET"] = "basket";
    AugmentedDataKeys["AUGMENTED_DATA_CUSTOMER"] = "customer";
    AugmentedDataKeys["AUGMENTED_DATA_CURRENCY"] = "currency";
    AugmentedDataKeys["AUGMENTED_DATA_ADDITIONAL_DATA"] = "additionalData";
    AugmentedDataKeys["AUGMENTED_DATA_PAYMENT"] = "payment";
    AugmentedDataKeys["AUGMENTED_DATA_CANCELLED"] = "cancelled";
    AugmentedDataKeys["AUGMENTED_DATA_REFERENCES"] = "references";
})(AugmentedDataKeys = exports.AugmentedDataKeys || (exports.AugmentedDataKeys = {}));
/**
 * Authorization methods for cards.
 */
var CardAuthorisationMethods;
(function (CardAuthorisationMethods) {
    CardAuthorisationMethods["CARD_AUTH_METHOD_PIN"] = "pin";
    CardAuthorisationMethods["CARD_AUTH_METHOD_SIGNATURE"] = "signature";
    CardAuthorisationMethods["CARD_AUTH_METHOD_FINGERPRINT"] = "fingerprint";
    CardAuthorisationMethods["CARD_AUTH_METHOD_RETINAL_SCAN"] = "rentinalScan";
})(CardAuthorisationMethods = exports.CardAuthorisationMethods || (exports.CardAuthorisationMethods = {}));
/**
 * Keys for additional information about cards.
 */
var CardDataKeys;
(function (CardDataKeys) {
    CardDataKeys["CARD_DATA_NETWORK"] = "network";
    CardDataKeys["CARD_DATA_ENTRY_METHOD"] = "entryMethod";
    CardDataKeys["CARD_DATA_AUTHORISATION_METHOD"] = "authorisationMethod";
    CardDataKeys["CARD_DATA_ACCOUNT_TYPE"] = "accountType";
    CardDataKeys["CARD_DATA_AID"] = "aid";
    CardDataKeys["CARD_DATA_SERVICE_CODE"] = "serviceCode";
    CardDataKeys["CARD_DATA_CVV"] = "cvv";
    CardDataKeys["CARD_DATA_LANGUAGES"] = "languages";
    CardDataKeys["CARD_DATA_BALANCE"] = "balance";
})(CardDataKeys = exports.CardDataKeys || (exports.CardDataKeys = {}));
/**
 * The standard set of card presentation methods.
 */
var CardEntryMethods;
(function (CardEntryMethods) {
    CardEntryMethods["CARD_ENTRY_METHOD_INSERT"] = "insert";
    CardEntryMethods["CARD_ENTRY_METHOD_SWIPE"] = "swipe";
    CardEntryMethods["CARD_ENTRY_METHOD_TAP"] = "tap";
    CardEntryMethods["CARD_ENTRY_METHOD_MANUAL"] = "manual";
})(CardEntryMethods = exports.CardEntryMethods || (exports.CardEntryMethods = {}));
/**
 * Card networks, also known as schemes.
 */
var CardNetworks;
(function (CardNetworks) {
    CardNetworks["CARD_NETWORK_MASTERCARD"] = "mastercard";
    CardNetworks["CARD_NETWORK_VISA"] = "visa";
    CardNetworks["CARD_NETWORK_AMEX"] = "amex";
    CardNetworks["CARD_NETWORK_DINERS"] = "diners";
    CardNetworks["CARD_NETWORK_JCB"] = "jcb";
    CardNetworks["CARD_NETWORK_UNION_PAY"] = "unionpay";
    CardNetworks["CARD_NETWORK_MAESTRO"] = "maestro";
})(CardNetworks = exports.CardNetworks || (exports.CardNetworks = {}));
/**
 * The main FPS event types.
 */
var EventTypes;
(function (EventTypes) {
    /**
       * When anything has changed in FPS related to settings, configurations, etc, this event will be triggered.
       * The data for the event will be populated with the relevant FPS state.
       * See {@link EventDataKeys} for breakdown of what has changed
       */
    EventTypes["EVENT_INTERNAL_STATE_CHANGED"] = "flowStateChanged";
    /**
       * When something external has changed, like devices connected/disconnected or apps added/removed/enabled/disabled, etc
       * See {@link EventDataKeys} for breakdown of what has changed
       */
    EventTypes["EVENT_EXTERNAL_STATE_CHANGED"] = "externalStateChanged";
})(EventTypes = exports.EventTypes || (exports.EventTypes = {}));
/**
 * Keys for different event flags.
 */
var EventDataKeys;
(function (EventDataKeys) {
    /**
       * For {@link EventTypes#EVENT_EXTERNAL_STATE_CHANGED} event.
       *
       * Flow services have changed, meaning apps should re-query for available flow services.
       */
    EventDataKeys["EVENT_KEY_FLOW_SERVICES_CHANGED"] = "eventKeyFlowServicesChanged";
    /**
       * For {@link EventTypes#EVENT_EXTERNAL_STATE_CHANGED} event.
       *
       * Devices have changed, meaning apps should re-query for available devices.
       */
    EventDataKeys["EVENT_KEY_DEVICES_CHANGED"] = "eventKeyDevicesChanged";
    /**
       * For {@link EventTypes#EVENT_INTERNAL_STATE_CHANGED} event.
       *
       * FPS settings have changed.
       */
    EventDataKeys["EVENT_KEY_SETTINGS_CHANGED"] = "eventKeySettingsChanged";
    /**
       * For {@link EventTypes#EVENT_INTERNAL_STATE_CHANGED} event.
       *
       * Flow configs have been updated.
       */
    EventDataKeys["EVENT_KEY_FLOW_CONFIGS_CHANGED"] = "eventKeyFlowConfigsChanged";
})(EventDataKeys = exports.EventDataKeys || (exports.EventDataKeys = {}));
var FlowTypes;
(function (FlowTypes) {
    FlowTypes["SALE"] = "sale";
    FlowTypes["REFUND"] = "refund";
    FlowTypes["MOTO_SALE"] = "motoSale";
    FlowTypes["MOTO_REFUND"] = "motoRefund";
    FlowTypes["PRE_AUTHORISATION"] = "preAuthorisation";
    FlowTypes["PRE_AUTH_COMPLETION"] = "preAuthCompletion";
    FlowTypes["DEPOSIT"] = "deposit";
    FlowTypes["REVERSAL"] = "reversal";
    FlowTypes["TOKENISATION"] = "tokenisation";
    FlowTypes["BATCH_CLOSURE"] = "batchClosure";
    FlowTypes["RECEIPT_DELIVERY"] = "receiptDelivery";
    FlowTypes["BASKET_STATUS_UPDATE"] = "basketStatusUpdate";
    FlowTypes["CUSTOMER_STATUS_UPDATE"] = "customerStatusUpdate";
    FlowTypes["DEVICE_SETTINGS"] = "deviceSettings";
    FlowTypes["PAYMENT_RESPONSE_QUERY"] = "paymentResponseQuery";
    FlowTypes["RESPONSE_QUERY"] = "responseQuery";
})(FlowTypes = exports.FlowTypes || (exports.FlowTypes = {}));
var FlowStages;
(function (FlowStages) {
    FlowStages["PRE_FLOW"] = "PRE_FLOW";
    FlowStages["SPLIT"] = "SPLIT";
    FlowStages["PRE_TRANSACTION"] = "PRE_TRANSACTION";
    FlowStages["PAYMENT_CARD_READING"] = "PAYMENT_CARD_READING";
    FlowStages["POST_CARD_READING"] = "POST_CARD_READING";
    FlowStages["TRANSACTION_PROCESSING"] = "TRANSACTION_PROCESSING";
    FlowStages["POST_TRANSACTION"] = "POST_TRANSACTION";
    FlowStages["POST_FLOW"] = "POST_FLOW";
    FlowStages["GENERIC"] = "GENERIC";
    FlowStages["POST_GENERIC"] = "POST_GENERIC";
    FlowStages["STATUS_UPDATE"] = "STATUS_UPDATE";
    FlowStages["FULFILLED_CHECK"] = "FULFILLED_CHECK";
})(FlowStages = exports.FlowStages || (exports.FlowStages = {}));
/**
 * Keys related to loyalty information.
 */
var LoyaltyDataKeys;
(function (LoyaltyDataKeys) {
    LoyaltyDataKeys["LOYALTY_SCHEME_NAME"] = "schemeName";
    LoyaltyDataKeys["LOYALTY_REWARDS_PROCESSED"] = "rewardsProcessed";
    LoyaltyDataKeys["LOYALTY_REWARD_MESSAGE"] = "rewardMessage";
    LoyaltyDataKeys["LOYALTY_TOTAL_POINTS"] = "totalPoints";
    LoyaltyDataKeys["LOYALTY_TOTAL_VALUE"] = "totalValue";
    LoyaltyDataKeys["LOYALTY_EARN_POINTS"] = "earnPoints";
    LoyaltyDataKeys["LOYALTY_EARN_VALUE"] = "earnValue";
    LoyaltyDataKeys["LOYALTY_REDEEM_POINTS"] = "redeemPoints";
    LoyaltyDataKeys["LOYALTY_REDEEM_VALUE"] = "redeemValue";
})(LoyaltyDataKeys = exports.LoyaltyDataKeys || (exports.LoyaltyDataKeys = {}));
var ModifierTypes;
(function (ModifierTypes) {
    ModifierTypes["TAX"] = "tax";
    ModifierTypes["EXTRA"] = "extra";
    ModifierTypes["DEDUCTION"] = "deduction";
    ModifierTypes["DISCOUNT"] = "discount";
})(ModifierTypes = exports.ModifierTypes || (exports.ModifierTypes = {}));
/**
 * Data that can be passed to payment apps in particular.
 */
var PaymentDataKeys;
(function (PaymentDataKeys) {
    PaymentDataKeys["DATA_KEY_MERCHANT_ID"] = "merchantId";
    /**
       * See {@link CardEntryMethods} for possible values.
       * Should be passed as a String[].
       */
    PaymentDataKeys["CARD_ENTRY_METHODS"] = "cardEntryMethods";
    /**
       * See {@link PaymentMethods} for possible values.
       * Should be passed as String[].
       */
    PaymentDataKeys["CARD_PAYMENT_METHODS"] = "paymentMethods";
    /**
       * Also known as card schemes.
       * See {@link CardNetworks} for possible values.
       * Should be passed as String[].
       */
    PaymentDataKeys["CARD_NETWORKS"] = "cardNetworks";
    /**
       * See {@link AccountTypes} for possible values.
       * Should be passed as String[].
       */
    PaymentDataKeys["ACCOUNT_TYPES"] = "accountTypes";
})(PaymentDataKeys = exports.PaymentDataKeys || (exports.PaymentDataKeys = {}));
/**
 * Defined methods of payment.
 */
var PaymentMethods;
(function (PaymentMethods) {
    PaymentMethods["PAYMENT_METHOD_CARD"] = "card";
    PaymentMethods["PAYMENT_METHOD_CREDIT_CARD"] = "creditCard";
    PaymentMethods["PAYMENT_METHOD_DEBIT_CARD"] = "debitCard";
    PaymentMethods["PAYMENT_METHOD_CHARGE_CARD"] = "chargeCard";
    PaymentMethods["PAYMENT_METHOD_CASH"] = "cash";
    PaymentMethods["PAYMENT_METHOD_LOYALTY_POINTS"] = "points";
    PaymentMethods["PAYMENT_METHOD_REWARD"] = "reward";
    PaymentMethods["PAYMENT_METHOD_GIFT_CARD"] = "giftCard";
    PaymentMethods["PAYMENT_METHOD_BANK_ACCOUNT"] = "bankAccount";
    PaymentMethods["PAYMENT_METHOD_CHEQUE"] = "cheque";
    PaymentMethods["PAYMENT_METHOD_EBT"] = "ebt";
    PaymentMethods["PAYMENT_METHOD_INVOICE"] = "invoice";
})(PaymentMethods = exports.PaymentMethods || (exports.PaymentMethods = {}));
/**
 * Receipt data keys for receipt related requests.
 */
var ReceiptKeys;
(function (ReceiptKeys) {
    ReceiptKeys["RECEIPT_PAYMENT_METHOD"] = "receiptPaymentMethod";
    ReceiptKeys["RECEIPT_AMOUNTS"] = "receiptAmounts";
    ReceiptKeys["RECEIPT_OUTCOME"] = "receiptOutcome";
    ReceiptKeys["RECEIPT_BASKET"] = "receiptBasket";
})(ReceiptKeys = exports.ReceiptKeys || (exports.ReceiptKeys = {}));
/**
 * Keys for reference data being passed back in responses
 */
var ReferenceKeys;
(function (ReferenceKeys) {
    ReferenceKeys["REFERENCE_KEY_MERCHANT_ID"] = "merchantId";
    ReferenceKeys["REFERENCE_KEY_MERCHANT_NAME"] = "merchantName";
    ReferenceKeys["REFERENCE_KEY_TERMINAL_ID"] = "terminalId";
    /**
       * ms since epoch
       *
       * The value of this parameter should be provided as a long
       */
    ReferenceKeys["REFERENCE_KEY_TRANSACTION_DATE_TIME"] = "transactionDateTime";
    /**
       * For terminals that provide a transaction number representing the count of transactions performed on a terminal so far.
       *
       * <strong>This is not the same as transactionId</strong>
       */
    ReferenceKeys["REFERENCE_KEY_TRANSACTION_NUMBER"] = "transactionNumber";
    ReferenceKeys["REFERENCE_KEY_PAYMENT_SERVICE"] = "paymentService";
})(ReferenceKeys = exports.ReferenceKeys || (exports.ReferenceKeys = {}));
/**
 * Keys for additional flow service info.
 */
var ServiceInfoDataKeys;
(function (ServiceInfoDataKeys) {
    ServiceInfoDataKeys["MERCHANTS"] = "merchants";
    ServiceInfoDataKeys["SUPPORTS_MANUAL_ENTRY"] = "supportsManualEntry";
    ServiceInfoDataKeys["PRINTS_RECEIPTS"] = "printsReceipts";
    ServiceInfoDataKeys["REQUIRES_CARD_TOKEN"] = "requiresCardToken";
})(ServiceInfoDataKeys = exports.ServiceInfoDataKeys || (exports.ServiceInfoDataKeys = {}));
/**
 * Data keys related to splitting transactions.
 */
var SplitDataKeys;
(function (SplitDataKeys) {
    SplitDataKeys["DATA_KEY_SPLIT_TXN"] = "splitTxn";
    SplitDataKeys["DATA_KEY_NUM_SPLITS"] = "numSplits";
    SplitDataKeys["DATA_KEY_SPLIT_TYPE"] = "splitType";
    SplitDataKeys["SPLIT_TYPE_BASKET"] = "splitBasketItems";
    SplitDataKeys["SPLIT_TYPE_AMOUNTS"] = "splitAmounts";
})(SplitDataKeys = exports.SplitDataKeys || (exports.SplitDataKeys = {}));
/**
 * Keys for status update data.
 */
var StatusUpdateKeys;
(function (StatusUpdateKeys) {
    // Basket keys
    StatusUpdateKeys["STATUS_UPDATE_BASKET_MODIFIED"] = "basketUpdated";
    StatusUpdateKeys["STATUS_UPDATE_BASKET_ITEMS_ADDED"] = "basketItemsAdded";
    StatusUpdateKeys["STATUS_UPDATE_BASKET_ITEMS_REMOVED"] = "basketItemsRemoved";
    StatusUpdateKeys["STATUS_UPDATE_BASKET_ITEM_MODIFIED"] = "basketItemUpdated";
    // Customer keys
    StatusUpdateKeys["STATUS_UPDATE_CUSTOMER"] = "customerUpdate";
})(StatusUpdateKeys = exports.StatusUpdateKeys || (exports.StatusUpdateKeys = {}));
/**
 * Defined set of error constants that may be passed back to the client.
 */
var ErrorConstants;
(function (ErrorConstants) {
    /**
       * A general purpose error that will be sent for fatal failures in a flow service
       */
    ErrorConstants["FLOW_SERVICE_ERROR"] = "flowServiceError";
    /**
       * Sent if the processing service if not installed
       */
    ErrorConstants["PROCESSING_SERVICE_NOT_INSTALLED"] = "notInstalled";
    /**
       * Sent if the processing service rejects a request because it is busy processing another
       */
    ErrorConstants["PROCESSING_SERVICE_BUSY"] = "busy";
    /**
       * Sent if the processing service fails to cancel a flow
       */
    ErrorConstants["PROCESSING_SERVICE_CANCEL_FAILED"] = "cancelFailed";
    /**
       * Sent if the processing service fails to resume a flow
       */
    ErrorConstants["PROCESSING_SERVICE_RESUME_FAILED"] = "resumeFailed";
    /**
       * Sent if an unknown/unsupported request type is sent to the processing service
       */
    ErrorConstants["UNSUPPORTED_OPERATION"] = "unsupportedOperation";
    /**
       * Sent if the processing service has received an unexpected message type
       */
    ErrorConstants["INVALID_MESSAGE_TYPE"] = "invalidMessageType";
    /**
       * Sent if the flow type or name in the request is not valid
       */
    ErrorConstants["INVALID_FLOW_IDENTIFIER"] = "invalidFlowIdentifier";
    /**
       * The processing service has received an invalid or unreadable message. This usually indicates a message has been corrupted.
       */
    ErrorConstants["INVALID_REQUEST"] = "invalidRequest";
    /**
       * Sent if the client application is missing a response listener service implementation
       */
    ErrorConstants["MISSING_RESPONSE_LISTENER"] = "missingResponseListener";
    /**
       * Sent if a flow service does not support the stage it has just been called for
       */
    ErrorConstants["STAGE_NOT_SUPPORTED"] = "stageNotSupported";
    /**
       * Sent if the processing service cannot find a handler(s) for a stage
       */
    ErrorConstants["CONFIG_ERROR"] = "configError";
    /**
       * Sent if the processing service detects there is more than one config provider installed that provides flow configs
       */
    ErrorConstants["MULTIPLE_CONFIG_PROVIDERS"] = "multipleConfigProviders";
    /**
       * Sent if the processing service detects there is no config provider installed that provides flow configs
       */
    ErrorConstants["NO_CONFIG_PROVIDER"] = "noConfigProvider";
    /**
       * Sent if there are no flow services installed on the device that can handle any requests
       */
    ErrorConstants["NO_FLOW_SERVICES"] = "noFlowServices";
    /**
       * Sent if there are no flows configured and/or accepted by FPS
       */
    ErrorConstants["NO_AVAILABLE_FLOWS"] = "noAvailableFlows";
    /**
       * Sent if the client is using an API that is not the same major version as the one implemented by the processing service
       */
    ErrorConstants["INCOMPATIBLE_API_VERSION"] = "incompatibleApiVersion";
    /**
       * Sent if the client sends a request with the same id as a previously initiated request
       */
    ErrorConstants["DUPLICATE_REQUEST_ID"] = "duplicateRequestId";
    /**
       * Something unexpected happened
       */
    ErrorConstants["UNEXPECTED_ERROR"] = "unexpectedError";
})(ErrorConstants = exports.ErrorConstants || (exports.ErrorConstants = {}));
