import { AdditionalData } from './additional-data';
import { Token } from './token';
import { Jsonable } from './jsonable';
import { JsonOption } from '../util/json-option';
export declare enum CustomerDataKeys {
    FIRST_NAME = "firstName",
    SURNAME = "surname",
    MIDDLE_NAMES = "middleNames",
    PHONE = "phone",
    EMAIL = "email",
    ADDRESS = "address",
    POSTCODE = "postcode",
    CITY = "city",
    STATE = "state",
    COUNTRY = "country"
}
/**
 * Represents a paying customer with associated customer details and tokens.
 */
export declare class Customer extends Jsonable {
    id: string;
    fullName: string;
    customerDetails: AdditionalData;
    tokens: Array<Token>;
    constructor();
    /**
       * Creates and returns a new Customer object based on the details given
       *
       * @param id The unique Id of the customer
       * @param fullName The customers full name
       * @param customerDetails Any other details to be associated with this customer see {@link CustomerDataKeys} for keys
       * @param tokens Any tokens that should be associated with this customer
       *
       * @returns The new Customer object
       */
    static from(id: string, fullName: string, customerDetails?: AdditionalData, tokens?: Array<Token>): Customer;
    /**
       * Convert a JSON string into an {@link Customer} object if possible
       *
       * @param json The JSON to convert
       */
    static fromJson(json: string): Customer;
    /**
       * Convenience wrapper for adding additional customer data.
       *
       * This can be used to set arbitrary data to be passed on in the request to down-stream flow apps and/or payment apps.
       *
       * See {@link AdditionalData#addData(String, Object[])} for more info.
       *
       * @param key    The key to use for this data
       * @param values An array of values for this data
       */
    addCustomerDetails(key: string, ...values: any | JsonOption): void;
}
