import { Jsonable } from './jsonable';
import { JsonOption } from '../util/json-option';
import { AdditionalData } from './additional-data';
export declare enum MerchantDataKeys {
    NAME = "name",
    PHONE = "phone",
    EMAIL = "email",
    ADDRESS = "address",
    POSTCODE = "postcode",
    CITY = "city",
    STATE = "state",
    COUNTRY = "country"
}
export declare enum MerchantTokenKeys {
    MARKETPLACE = "marketplace",
    AEVIPAY = "aevipay",
    UMP = "ump"
}
/**
 * A model to store merchant data such as address and contact details
 */
export declare class Merchant extends Jsonable {
    umpId: string;
    name: string;
    details: AdditionalData;
    tokens: AdditionalData;
    /**
       * Create a new merchant object using the details given
       *
       * @param umpId The unique Unified Merchant Portal (UMP) id of this merchant
       * @param name The name of the merchant
       * @param details All other details for this merchant stored as a
       * @param tokens A collection of {@link Token} objects that give this merchant access to the various external services
       */
    static from(umpId: string, name: string, details?: AdditionalData, tokens?: AdditionalData): Merchant;
    /**
       * Convert a JSON string into an {@link Merchant} object if possible
       *
       * @param json The JSON to convert
       */
    static fromJson(json: string): Merchant;
    /**
       * Convenience wrapper for adding additional merchant data.
       *     *
       * See {@link AdditionalData#addData(String, Object[])} for more info.
       *
       * @param key    The key to use for this data
       * @param values An array of values for this data
       */
    addMerchantDetails(key: string, ...values: any | JsonOption): void;
}
