"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const payment_builder_1 = require("./payment-builder");
const amounts_1 = require("./amounts");
const token_1 = require("./token");
const pre_conditions_1 = require("../util/pre-conditions");
const basket_1 = require("./basket");
const basket_item_builder_1 = require("./basket-item-builder");
describe('PaymentBuilder', () => {
    it('can build a valid request', () => {
        const amounts = amounts_1.Amounts.from(2000, 'GBP');
        const payment = new payment_builder_1.PaymentBuilder().withPaymentFlow('sale').withAmounts(amounts).build();
        expect(payment.amounts).toStrictEqual(amounts);
        expect(payment.flowType).toBe('sale');
    });
    it('should not allow card token and split together', () => {
        const amounts = amounts_1.Amounts.from(2000, 'GBP');
        expect(() => {
            new payment_builder_1.PaymentBuilder().withPaymentFlow('sale').withAmounts(amounts).withSplitEnabled(true)
                .withCardToken(token_1.Token.from('1232', 'card'))
                .build();
        }).toThrow(pre_conditions_1.InvalidArgumentError);
    });
    it('should not allow basket and amounts total mismatch', () => {
        const amounts = amounts_1.Amounts.from(2000, 'GBP');
        const basket = basket_1.Basket.fromItems('test', new basket_item_builder_1.BasketItemBuilder().generateRandomId().withLabel('bla').withAmount(900)
            .build());
        expect(() => {
            new payment_builder_1.PaymentBuilder().withPaymentFlow('sale').withAmounts(amounts).withBasket(basket)
                .build();
        }).toThrow(pre_conditions_1.InvalidArgumentError);
    });
});
