"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var PaymentFlowServices_1;
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const json2typescript_1 = require("json2typescript");
const payment_flow_service_info_1 = require("./payment-flow-service-info");
/**
 * Exposes payment and flow services information with helper methods to retrieve collated data across all services.
 */
let PaymentFlowServices = PaymentFlowServices_1 = class PaymentFlowServices {
    constructor() {
        this.paymentFlowServiceInfoList = [];
        this.supportedRequestTypes = [];
        this.supportedCurrencies = [];
        this.supportedPaymentMethods = [];
        this.supportedDataKeys = [];
    }
    static from(paymentFlowServiceInfoList) {
        const pfs = new PaymentFlowServices_1();
        pfs.paymentFlowServiceInfoList = paymentFlowServiceInfoList;
        for (const paymentFlowServiceInfo of paymentFlowServiceInfoList) {
            // FIXME should be set
            pfs.supportedRequestTypes = this.union(paymentFlowServiceInfo.customRequestTypes, pfs.supportedRequestTypes);
            pfs.supportedCurrencies = this.union(paymentFlowServiceInfo.supportedCurrencies, pfs.supportedCurrencies);
            pfs.supportedPaymentMethods = this.union(paymentFlowServiceInfo.paymentMethods, pfs.supportedPaymentMethods);
            pfs.supportedDataKeys = this.union(paymentFlowServiceInfo.supportedDataKeys, pfs.supportedDataKeys);
        }
        return pfs;
    }
    static union(source, target) {
        for (const src of source) {
            if (!target.find((x) => x === src)) {
                target.push(src);
            }
        }
        return target;
    }
    /**
       * Get the flow service with the provided id.
       *
       * @param id The flow service id
       * @return An instance of PaymentFlowServiceInfo if a match was found, or null otherwise
       */
    getFlowServiceFromId(id) {
        for (const serviceInfo of this.paymentFlowServiceInfoList) {
            if (serviceInfo.id === id) {
                return serviceInfo;
            }
        }
        return null;
    }
};
__decorate([
    json2typescript_1.JsonProperty('paymentFlowServiceInfoList', [payment_flow_service_info_1.PaymentFlowServiceInfo]),
    __metadata("design:type", Array)
], PaymentFlowServices.prototype, "paymentFlowServiceInfoList", void 0);
__decorate([
    json2typescript_1.JsonProperty('supportedRequestTypes', [String]),
    __metadata("design:type", Array)
], PaymentFlowServices.prototype, "supportedRequestTypes", void 0);
__decorate([
    json2typescript_1.JsonProperty('supportedCurrencies', [String]),
    __metadata("design:type", Array)
], PaymentFlowServices.prototype, "supportedCurrencies", void 0);
__decorate([
    json2typescript_1.JsonProperty('supportedPaymentMethods', [String]),
    __metadata("design:type", Array)
], PaymentFlowServices.prototype, "supportedPaymentMethods", void 0);
__decorate([
    json2typescript_1.JsonProperty('supportedDataKeys', [String]),
    __metadata("design:type", Array)
], PaymentFlowServices.prototype, "supportedDataKeys", void 0);
PaymentFlowServices = PaymentFlowServices_1 = __decorate([
    json2typescript_1.JsonObject('PaymentFlowServices')
], PaymentFlowServices);
exports.PaymentFlowServices = PaymentFlowServices;
