import { TransactionResponse } from './transaction-response';
import { Payment } from './payment';
import { Amounts } from './amounts';
import { Transaction } from './transaction';
import { FlowAppInfo } from './flow-app-info';
import { Basket } from './basket';
import { Jsonable } from './jsonable';
export declare enum Outcome {
    FULFILLED = "FULFILLED",
    PARTIALLY_FULFILLED = "PARTIALLY_FULFILLED",
    FAILED = "FAILED"
}
export declare enum FailureReason {
    NONE = "NONE",
    CANCELLED = "CANCELLED",
    REJECTED = "REJECTED",
    DECLINED = "DECLINED",
    TIMEOUT = "TIMEOUT",
    ERROR = "ERROR"
}
/**
 * Response for a previously made {@link Payment}.
 *
 * A payment can lead to a single or multiple transactions and it is up to the client to ensure this is taken into account.
 *
 * This class contains convenience methods to get overall information for the transaction processing.
 */
export declare class PaymentResponse extends Jsonable {
    id: string;
    originatingPayment: Payment;
    outcome: Outcome;
    failureReason: FailureReason;
    failureMessage?: string;
    allTransactionsApproved: boolean;
    totalAmountsRequested: Amounts;
    totalAmountsProcessed: Amounts;
    transactions: Array<Transaction>;
    creationDateTimeMs: number;
    executedPreFlowApp?: FlowAppInfo;
    executedPostFlowApp?: FlowAppInfo;
    /**
       * Convert a JSON string into an {@link PaymentResponse} object if possible
       *
       * @param json The JSON to convert
       */
    static fromJson(json: string): PaymentResponse;
    getFlowType(): string;
    getDisplayDate(): string;
    getDisplayDateTime(): string;
    getCurrency(): string;
    getTransactions(): Array<Transaction>;
    getTransactionResponses(): Array<TransactionResponse>;
    getLastResponse(): TransactionResponse;
    getRequestedBasket(): Basket;
    getBaskets(): Array<Basket>;
}
