"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var PaymentResponse_1;
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const json2typescript_1 = require("json2typescript");
const payment_1 = require("./payment");
const amounts_1 = require("./amounts");
const transaction_1 = require("./transaction");
const flow_app_info_1 = require("./flow-app-info");
const jsonable_1 = require("./jsonable");
// BAC > these are typescript conversions of the AppFlow payment initiation models
var Outcome;
(function (Outcome) {
    Outcome["FULFILLED"] = "FULFILLED";
    Outcome["PARTIALLY_FULFILLED"] = "PARTIALLY_FULFILLED";
    Outcome["FAILED"] = "FAILED";
})(Outcome = exports.Outcome || (exports.Outcome = {}));
var FailureReason;
(function (FailureReason) {
    FailureReason["NONE"] = "NONE";
    FailureReason["CANCELLED"] = "CANCELLED";
    FailureReason["REJECTED"] = "REJECTED";
    FailureReason["DECLINED"] = "DECLINED";
    FailureReason["TIMEOUT"] = "TIMEOUT";
    FailureReason["ERROR"] = "ERROR";
})(FailureReason = exports.FailureReason || (exports.FailureReason = {}));
/**
 * Response for a previously made {@link Payment}.
 *
 * A payment can lead to a single or multiple transactions and it is up to the client to ensure this is taken into account.
 *
 * This class contains convenience methods to get overall information for the transaction processing.
 */
let PaymentResponse = PaymentResponse_1 = class PaymentResponse extends jsonable_1.Jsonable {
    constructor() {
        super(...arguments);
        this.id = undefined;
        this.originatingPayment = undefined;
        this.outcome = undefined;
        this.failureReason = undefined;
        this.failureMessage = undefined;
        this.allTransactionsApproved = undefined;
        this.totalAmountsRequested = undefined;
        this.totalAmountsProcessed = undefined;
        this.transactions = undefined;
        this.creationDateTimeMs = undefined;
        this.executedPreFlowApp = undefined;
        this.executedPostFlowApp = undefined;
    }
    /**
       * Convert a JSON string into an {@link PaymentResponse} object if possible
       *
       * @param json The JSON to convert
       */
    static fromJson(json) {
        return jsonable_1.Jsonable.baseFromJson(json, PaymentResponse_1);
    }
    getFlowType() {
        return this.originatingPayment.flowType;
    }
    getDisplayDate() {
        const formatter = Intl.DateTimeFormat('en-GB');
        return formatter.format(this.creationDateTimeMs);
    }
    getDisplayDateTime() {
        const formatter = Intl.DateTimeFormat('en-GB', {
            year: 'numeric',
            month: 'numeric',
            day: 'numeric',
            hour: 'numeric',
            minute: 'numeric',
            second: 'numeric',
        });
        return formatter.format(this.creationDateTimeMs);
    }
    getCurrency() {
        return this.totalAmountsProcessed.currency;
    }
    getTransactions() {
        return this.transactions;
    }
    getTransactionResponses() {
        // BAC - At this time every payment service we have will only return a single transaction response
        return this.transactions[0].transactionResponses;
    }
    getLastResponse() {
        // BAC - Assuming there is only one response FIXME
        const last = this.transactions[0].transactionResponses.length - 1;
        return this.transactions[0].transactionResponses[last];
    }
    getRequestedBasket() {
        // BAC - This is the basket the POS app requested
        return this.originatingPayment.basket;
    }
    getBaskets() {
        // BAC - This is the basket that was associated with the transaction. We are assuming only one Transaction and one Basket in that transaction
        return this.transactions[0].baskets;
    }
};
__decorate([
    json2typescript_1.JsonProperty('id'),
    __metadata("design:type", String)
], PaymentResponse.prototype, "id", void 0);
__decorate([
    json2typescript_1.JsonProperty('originatingPayment', payment_1.Payment),
    __metadata("design:type", payment_1.Payment)
], PaymentResponse.prototype, "originatingPayment", void 0);
__decorate([
    json2typescript_1.JsonProperty('outcome', String),
    __metadata("design:type", String)
], PaymentResponse.prototype, "outcome", void 0);
__decorate([
    json2typescript_1.JsonProperty('failureReason', String),
    __metadata("design:type", String)
], PaymentResponse.prototype, "failureReason", void 0);
__decorate([
    json2typescript_1.JsonProperty('failureMessage', String, true),
    __metadata("design:type", String)
], PaymentResponse.prototype, "failureMessage", void 0);
__decorate([
    json2typescript_1.JsonProperty('allTransactionsApproved'),
    __metadata("design:type", Boolean)
], PaymentResponse.prototype, "allTransactionsApproved", void 0);
__decorate([
    json2typescript_1.JsonProperty('totalAmountsRequested', amounts_1.Amounts),
    __metadata("design:type", amounts_1.Amounts)
], PaymentResponse.prototype, "totalAmountsRequested", void 0);
__decorate([
    json2typescript_1.JsonProperty('totalAmountsProcessed', amounts_1.Amounts),
    __metadata("design:type", amounts_1.Amounts)
], PaymentResponse.prototype, "totalAmountsProcessed", void 0);
__decorate([
    json2typescript_1.JsonProperty('transactions', [transaction_1.Transaction]),
    __metadata("design:type", Array)
], PaymentResponse.prototype, "transactions", void 0);
__decorate([
    json2typescript_1.JsonProperty('creationDateTimeMs'),
    __metadata("design:type", Number)
], PaymentResponse.prototype, "creationDateTimeMs", void 0);
__decorate([
    json2typescript_1.JsonProperty('executedPreFlowApp', flow_app_info_1.FlowAppInfo, true),
    __metadata("design:type", flow_app_info_1.FlowAppInfo)
], PaymentResponse.prototype, "executedPreFlowApp", void 0);
__decorate([
    json2typescript_1.JsonProperty('executedPostFlowApp', flow_app_info_1.FlowAppInfo, true),
    __metadata("design:type", flow_app_info_1.FlowAppInfo)
], PaymentResponse.prototype, "executedPostFlowApp", void 0);
PaymentResponse = PaymentResponse_1 = __decorate([
    json2typescript_1.JsonObject('PaymentResponse')
], PaymentResponse);
exports.PaymentResponse = PaymentResponse;
