import { Jsonable } from './jsonable';
import { AdditionalData } from './additional-data';
/**
 * Generic request that at minimum contains a request type and optionally flow name and bespoke request data.
 *
 * If a flow name is set, the flow with that name will be explicitly used. If not set, the request type will be used to look up eligible flows
 * and one will be selected either automatically or via user interaction.
 *
 * @tsoaModel
 */
export declare class Request extends Jsonable {
    id: string;
    requestType: string;
    requestData: AdditionalData;
    flowName?: string;
    deviceId?: string;
    source?: string;
    targetAppId?: string;
    processInBackground: boolean;
    constructor();
    /**
       * Initialise a request with a request type and data.
       *
       * The request type will be used to assign the correct flow for this request.
       *
       * Please use [[flowName]] to explicitly specify what flow to use.
       *
       * See reference values in the documentation for possible values.
       *
       * @param requestType The request type
       * @param requestData The data for the request
       *
       * @returns The initialised request
       */
    static from(requestType: string, requestData?: AdditionalData): Request;
    /**
       * Convert a JSON string into a {@link Request} object if possible
       *
       * @param json The JSON to convert
       *
       * @returns A Request object
       */
    static fromJson(json: string): Request;
}
