"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var Request_1;
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const json2typescript_1 = require("json2typescript");
const uuid_1 = require("uuid");
const jsonable_1 = require("./jsonable");
const additional_data_1 = require("./additional-data");
/**
 * Generic request that at minimum contains a request type and optionally flow name and bespoke request data.
 *
 * If a flow name is set, the flow with that name will be explicitly used. If not set, the request type will be used to look up eligible flows
 * and one will be selected either automatically or via user interaction.
 *
 * @tsoaModel
 */
let Request = Request_1 = class Request extends jsonable_1.Jsonable {
    constructor() {
        super();
        this.id = undefined;
        this.requestType = undefined;
        this.requestData = new additional_data_1.AdditionalData();
        this.flowName = undefined;
        this.deviceId = undefined;
        this.source = undefined;
        this.targetAppId = undefined;
        this.processInBackground = false;
        this.id = uuid_1.v4();
    }
    /**
       * Initialise a request with a request type and data.
       *
       * The request type will be used to assign the correct flow for this request.
       *
       * Please use [[flowName]] to explicitly specify what flow to use.
       *
       * See reference values in the documentation for possible values.
       *
       * @param requestType The request type
       * @param requestData The data for the request
       *
       * @returns The initialised request
       */
    static from(requestType, requestData = new additional_data_1.AdditionalData()) {
        const request = new Request_1();
        request.requestType = requestType;
        request.requestData = requestData;
        return request;
    }
    /**
       * Convert a JSON string into a {@link Request} object if possible
       *
       * @param json The JSON to convert
       *
       * @returns A Request object
       */
    static fromJson(json) {
        return this.baseFromJson(json, Request_1);
    }
};
__decorate([
    json2typescript_1.JsonProperty('id'),
    __metadata("design:type", String)
], Request.prototype, "id", void 0);
__decorate([
    json2typescript_1.JsonProperty('requestType'),
    __metadata("design:type", String)
], Request.prototype, "requestType", void 0);
__decorate([
    json2typescript_1.JsonProperty('requestData', additional_data_1.AdditionalData),
    __metadata("design:type", additional_data_1.AdditionalData)
], Request.prototype, "requestData", void 0);
__decorate([
    json2typescript_1.JsonProperty('flowName', String, true),
    __metadata("design:type", String)
], Request.prototype, "flowName", void 0);
__decorate([
    json2typescript_1.JsonProperty('deviceId', String, true),
    __metadata("design:type", String)
], Request.prototype, "deviceId", void 0);
__decorate([
    json2typescript_1.JsonProperty('source', String, true),
    __metadata("design:type", String)
], Request.prototype, "source", void 0);
__decorate([
    json2typescript_1.JsonProperty('targetAppId', String, true),
    __metadata("design:type", String)
], Request.prototype, "targetAppId", void 0);
__decorate([
    json2typescript_1.JsonProperty('processInBackground'),
    __metadata("design:type", Boolean)
], Request.prototype, "processInBackground", void 0);
Request = Request_1 = __decorate([
    json2typescript_1.JsonObject('Request'),
    __metadata("design:paramtypes", [])
], Request);
exports.Request = Request;
