import { PaymentClient, PaymentClientOptions } from './payment-client';
export interface PaymentApi {
    /**
       * Get the API version.
       *
       * The API versioning follows semver rules with major.minor.patch versions.
       *
       * @return A Promise that will resolve to the current API version
       */
    getApiVersion(): Promise<string>;
    /**
       * Returns true if the processing service that handles API requests is installed.
       *
       * If not installed, none of the API calls will function.
       *
       * @return A Promise that will resolve to True if API processing service is installed, false otherwise
       */
    isProcessingServiceInstalled(): Promise<boolean>;
    /**
       * Get the processing service version installed on this device.
       *
       * @return A promise that will resolve to the processing service version (semver format)
       */
    getProcessingServiceVersion(): Promise<string>;
    /**
       * Get a new instance of a {@link PaymentClient} to initiate payments.
       *
       * @param options An optional list of key value pairs used to setup the payment client implentation
       *
       * @return An instance of {@link PaymentClient}
       */
    getPaymentClient(options?: PaymentClientOptions): PaymentClient;
}
