"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
const payment_1 = require("../../lib/model/payment");
const payment_builder_1 = require("../../lib/model/payment-builder");
const amounts_1 = require("../../lib/model/amounts");
describe('Payment', () => {
    it('should create an instance', () => {
        expect(new payment_1.Payment()).toBeTruthy();
    });
    it('should serialise and deserialise correctly', () => {
        const amounts = amounts_1.Amounts.from(20, 'GBP');
        const payment = new payment_builder_1.PaymentBuilder().withPaymentFlow('sale').withAmounts(amounts).build();
        const json = payment.toJson();
        const paymentResult = payment_1.Payment.fromJson(json);
        expect(paymentResult.amounts).toStrictEqual(amounts);
        expect(paymentResult).toStrictEqual(payment);
    });
    it('invalid json will throw', () => {
        expect(() => { payment_1.Payment.fromJson('{}ajksjkdj'); }).toThrow(SyntaxError);
    });
});
